@@ -64,8 +64,10 @@
 #' (x.wb <- monthlyWB(AWC, PPT, PET, S_init = 0))
 #' 
 #' # plot the results
+#' op <- par(no.readonly = TRUE)
+#' 
 #' par(mar=c(4,4,2,1), bg = 'white')
-#' plotWB(WB = x.wb, AWC = AWC)
+#' plotWB(WB = x.wb)
 #' 
 #' # compute fraction of AWC filled after the last month of simulation
 #' (last.S <- x.wb$S[12] / AWC)
@@ -73,9 +75,14 @@
 #' # re-run the water balance with this value
 #' (x.wb <- monthlyWB(AWC, PPT, PET, S_init = last.S))
 #' 
-#' # not much difference
+#' # interesting...
 #' par(mar=c(4,4,2,1), bg = 'white')
-#' plotWB(WB = x.wb, AWC = AWC)
+#' plotWB(WB = x.wb)
+#' 
+#' # note: consider using `rep = 3, keep_last = TRUE` 
+#' # to "warm-up" the water balance first
+#' 
+#' par(op)
 #' 
 #' }
 #' 
@@ -107,17 +114,39 @@ monthlyWB <- function(AWC, PPT, PET, S_init = AWC, starting_month = 1, rep = 1,
   
   ## Note: not using simpleWB() at this time
   
-  # Sb: total water storage (mm), this is the satiated VWC
-  # fc field capacity fraction: fraction of Sb, using 0.5 for a monthly timestep seems reasonable
+  ## bug? in hydromad::bucket.sim()
+  # ET[t] should not be greater than PPT[t] or S[t] when S_prev = 0
+  # 
+  # https://github.com/josephguillaume/hydromad/blob/master/R/bucket.R
+  
+  ## sharpshootR-specific
+  # https://github.com/ncss-tech/sharpshootR/issues/40
+  
+  ## opened issue
+  # https://github.com/josephguillaume/hydromad/issues/188
+  #
+  # Sb: total water storage (mm), this is the awc at monthly timestep
+  # fc field capacity fraction: fraction of Sb, 1 for a monthly timestep seems reasonable
   # S_0 initial moisture content as fraction of Sb 
   # a.ss should always be > 0, but very small at this time step
-  m <- hydromad::hydromad(d, sma = "bucket", routing = NULL)
-  m <- update(m, Sb = AWC, fc = fc, S_0 = S_init, a.ss = a.ss, M = 0, etmult = 1, a.ei = 0)
-  res <- predict(m, return_state = TRUE)
+  # m <- hydromad::hydromad(d, sma = "bucket", routing = NULL)
+  # m <- update(m, Sb = AWC, fc = fc, S_0 = S_init, a.ss = a.ss, M = 0, etmult = 1, a.ei = 0)
+  # res <- predict(m, return_state = TRUE)
   
+  ## until resolved:
+  # internal version, based on 
+  # https://github.com/josephguillaume/hydromad/blob/master/R/bucket.R
+  # with change:
+  # ET[t] <- Eintc + min(S[t], (Etrans + Ebare))
+  res <- .leakyBucket(d, Sb = AWC, fc = fc, S_0 = S_init, a.ss = a.ss, M = 0, etmult = 1, a.ei = 0)
+  
+  
+  # combine original PPT,PET with results
   res <- data.frame(d, res)
   
+  # cleanup names
   names(res) <- c('PPT', 'PET', 'U', 'S', 'ET')
+  # compute deficit: AET - PET
   res$D <- with(res, ET - PET)
   
   # add month index
@@ -126,10 +155,16 @@ monthlyWB <- function(AWC, PPT, PET, S_init = AWC, starting_month = 1, rep = 1,
   
   # optionally keep the last cycle
   if(keep_last) {
-    keep.idx <- seq(from=nrow(res) - (n-1), to = nrow(res), by = 1)
+    keep.idx <- seq(from = nrow(res) - (n-1), to = nrow(res), by = 1)
     res <- res[keep.idx, ]
   }
   
+  # reset rownames
+  row.names(res) <- NULL
+  
+  # add original AWC used as an attribute
+  attr(res, 'AWC') <- AWC
+  
   # done
   return(res)
 }
